@@ -1,4 +1,4 @@
-# $Id: config.pl,v 1.2 2006/09/04 10:21:29 khlut Exp $
+#
 # Work with config file
 #
 #Copyright 2005 Elphel, Inc.
@@ -59,13 +59,9 @@ sub file_dialog
       file:
         $dlg = Gtk2::FileSelection->new($cfg{$_}[2]);
 	$dlg->set_filename($cfg{$_}[0]);
-	print $dlg, "\n";
-	print $dlg->main_vbox, "\n";
 	$dlg->main_vbox->pack_end(Gtk2::Label->new($cfg{$_}[3]), 0,0,0);
 	my $text=Gtk2::Label->new("You may change this parameters editing file\n\"$conffile\"");
 	$text->set_line_wrap(1); $text->set_justify('center');
-	print $text, "\n";
-	print $dlg->main_vbox, "\n";
 	$dlg->main_vbox->pack_start($text,0,0,10);
 	push @wdg, $dlg;
       next;
